Please see [https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/generate-mlperf-tiny-report](https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/generate-mlperf-tiny-report) for the documentation of this CM script.
